BlockIO

Trait BlockIO 

pub trait BlockIO {
    // Required methods
    fn read_block(
        &self,
        tier: Tier,
        key: BlockKey,
        dst: &mut [u8],
    ) -> Result<usize, StoreError>;
    fn write_block(
        &mut self,
        tier: Tier,
        key: BlockKey,
        src: &[u8],
    ) -> Result<(), StoreError>;
    fn delete_block(
        &mut self,
        tier: Tier,
        key: BlockKey,
    ) -> Result<(), StoreError>;
}
Block I/O for reading and writing raw quantized data.

Required Methods

fn read_block( &self, tier: Tier, key: BlockKey, dst: &mut [u8], ) -> Result<usize, StoreError>

Read quantized bytes for key from the given tier into dst. Returns the number of bytes written to dst.

fn write_block( &mut self, tier: Tier, key: BlockKey, src: &[u8], ) -> Result<(), StoreError>

Write raw quantized bytes src for key into the given tier.

fn delete_block(&mut self, tier: Tier, key: BlockKey) -> Result<(), StoreError>

Delete the raw data for key from the given tier.

Implementors