tick_decay

Function tick_decay 

pub fn tick_decay(config: &TierConfig, meta: &mut BlockMeta)
Decay EMA for blocks not accessed in the current tick.

Should be called once per tick for every block that was not touched. Applies ema_rate *= (1 - alpha) and shifts the access window left by 1 (inserting a 0 bit).